==> nextcloud-19.0.6.tgz: nextcloud/apps/comments/l10n/bg.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментари",
    "You commented" : "Вие коментирахте",
    "%1$s commented" : "%1$s коментира",
    "{author} commented" : "{author} коментира",
    "You commented on %1$s" : "Ти коментира за %1$s",
    "You commented on {file}" : "Ти коментира за {file}",
    "%1$s commented on %2$s" : "%1$s коментиран за %2$s",
    "{author} commented on {file}" : "{author} коментира за {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментари</strong> за файлове",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Бяхте споменат/а към “{file}”, в коментар от потребител, който вече е изтрит",
    "{user} mentioned you in a comment on “{file}”" : "{user} те спомена в коментар за “{file}”",
    "Edit comment" : "Редактирай коментра",
    "Delete comment" : "Изтрий коментар",
    "No comments yet, start the conversation!" : "Все още няма коментари, започнете разговор!",
    "Retry" : "Опитай отново",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочетен коментар","%n непрочетени коментари"],
    "Comment" : "Коментар",
    "New comment …" : "Нов коментар...",
    "Post" : "Публикация",
    "Cancel" : "Отказ",
    "[Deleted user]" : "[Изтрит потребител]",
    "More comments …" : "Още коментари...",
    "Save" : "Запазване",
    "Allowed characters {count} of {max}" : "Позволени символи {count} от {max}",
    "Error occurred while updating comment with id {id}" : "Възникна грешка по време на обновяване на коментар с код {id}",
    "Error occurred while posting comment" : "Възникна грешка по време на изпращане на коментар"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.8p0.tgz: nextcloud/apps/comments/l10n/bg.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментари",
    "You commented" : "Вие коментирахте",
    "%1$s commented" : "%1$s коментира",
    "{author} commented" : "{author} коментира",
    "You commented on %1$s" : "Ти коментира за %1$s",
    "You commented on {file}" : "Ти коментира за {file}",
    "%1$s commented on %2$s" : "%1$s коментиран за %2$s",
    "{author} commented on {file}" : "{author} коментира за {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментари</strong> за файлове",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Бяхте споменат/а към “{file}”, в коментар от потребител, който вече е изтрит",
    "{user} mentioned you in a comment on “{file}”" : "{user} те спомена в коментар за “{file}”",
    "Files app plugin to add comments to files" : "Добавка на приложението Файлове за добавяне на коментари към файловете",
    "Edit comment" : "Редактирай коментра",
    "Delete comment" : "Изтрий коментар",
    "Cancel edit" : "Отказ на редактиране",
    "Post comment" : "Публикуване на коментар",
    "No comments yet, start the conversation!" : "Все още няма коментари, започнете разговор!",
    "No more messages" : " Няма повече съобщения",
    "Retry" : "Опитай отново",
    "Unable to load the comments list" : "Списъкът с коментари не може да се зареди",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочетен коментар","%n непрочетени коментари"],
    "_1 new comment_::_{unread} new comments_" : ["{unread} нови коментари","{unread} нови коментари"],
    "Comment" : "Коментар",
    "An error occurred while trying to edit the comment" : "Възникна грешка при опит за редактиране на коментара",
    "Comment deleted" : " Изтрит е коментар",
    "An error occurred while trying to delete the comment" : "Възникна грешка при опит за изтриване на коментара",
    "An error occurred while trying to create the comment" : "Възникна грешка при опит за създаване на коментар",
    "New comment …" : "Нов коментар...",
    "Post" : "Публикация",
    "Cancel" : "Отказ",
    "[Deleted user]" : "[Изтрит потребител]",
    "More comments …" : "Още коментари...",
    "Save" : "Запазване",
    "Allowed characters {count} of {max}" : "Позволени символи {count} от {max}",
    "Error occurred while retrieving comment with ID {id}" : "Възникна грешка по време на извличане на коментар с ID {id}",
    "Error occurred while updating comment with id {id}" : "Възникна грешка по време на обновяване на коментар с код {id}",
    "Error occurred while posting comment" : "Възникна грешка по време на изпращане на коментар"
},
"nplurals=2; plural=(n != 1);");
